@@ -1,10 +1,4 @@
 package DBIx::Patcher;
-BEGIN {
-  $DBIx::Patcher::VERSION = '0.03.01';
-}
-BEGIN {
-  $DBIx::Patcher::DIST = 'DBIx-Patcher';
-}
 use strict;
 use warnings;
 use FindBin::libs;
@@ -17,18 +11,7 @@ use DBIx::Patcher::Schema;
 use IO::File;
 use Digest::MD5;
 
-=pod
-
-=head1 NAME
-
-DBIx::Patcher - store history of patches applied in database schema
-
-=head1 VERSION
-
-version 0.03.01
-
-=cut
-
+our $VERSION = '0.01';
 
 $|=1;
 our $opts = {
@@ -68,12 +51,8 @@ sub run {
         'verbose'   => \$opts->{verbose},
         'debug'     => \$opts->{debug},
 #        'dry'       => \$opts->{dry},
-        'version'     => \$opts->{version},
-        
     );
 
-    _version() if ($opts->{version});
-
     # FIXME: do we need to use a plugin?
     # merge in defaults into opt and share plugin
     $opts->{chop} = Path::Class::Dir->new(
@@ -118,10 +97,6 @@ sub run {
     print "file: ". scalar @files ."\n" if ($opts->{debug});
 }
 
-sub _version {
-    print "  ". __PACKAGE__ ." $DBIx::Patcher::VERSION Jason Tang\n\n";
-    exit;
-}
 
 sub _patch_it {
     my($run,$file) = @_;
@@ -247,88 +222,28 @@ sub _install_me {
 
 1;
 __END__
+=pod
+
+=head1 NAME patcher
 
 =head1 SYNOPSIS
 
-    # add patches already run on an existing db
-    patcher -h db-server -u bob -d my_db sql/0.01 --add
-
-    # running from within the location where the app/sql lives
-    patcher -h db-server -u bob -d my_db sql/0.01
-
-    # run patcher from anywhere and store filename correctly
-    patcher -h db-server -u bob -d my_db /opt/app/sql/0.01 -c /opt/app
-
-    # to retry previously failed patches
-    patcher -h db-server -u bob -d my_db sql/0.01 --retry
-
-=head1 DESCRIPTION
+patcher [-h localhost] [-u www] [-d my_db] patch_dir
 
 =head1 OPTIONS
 
 =head2 --install
 
-TBA - install the patcher schema before doing anything else
+=head2 --host
 
-=head2 --host -h
+=head2 --user
 
-Host of the database. Defaults to localhost
+=head2 --database
 
-=head2 --user -u
+=head2
 
-User for connecting to the database. Defaults to www
+=head2
 
-=head2 --database -d
+=head1
 
-Name of the database
-
-=head2 --chop -c
-
-When patching remove this from the absolute path of the patch file to make
-the logging of patches relative from a certain point. Defaults to $PWD
-
-=head2 --retry
-
-For patches that have failed retry
-
-=head2 --add -a
-
-Any files found that haven't been run, just add them as if they run successfully
-
-=head2 --plugin
-
-TBA - specify a plugin to load and provide defaults/custom handling
-
-=head1 AUTHOR
-
-Jason Tang, C<< <tang.jason.ch at gmail.com> >>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-dbix-patch at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx-Patcher>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SEE ALSO
-
-DBIx::Class
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc DBix::Patcher
-
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2011 Jason Tang.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
-
-=cut
\ No newline at end of file
+=cut
