@@ -1,10 +1,4 @@
 package DBIx::Patcher::Schema::ResultSet::Patcher::Patch;
-BEGIN {
-  $DBIx::Patcher::Schema::ResultSet::Patcher::Patch::VERSION = '0.03.01';
-}
-BEGIN {
-  $DBIx::Patcher::Schema::ResultSet::Patcher::Patch::DIST = 'DBIx-Patcher';
-}
 # vim: ts=8 sts=4 et sw=4 sr sta
 use strict;
 use warnings;
